Index: Ringtoets/AssemblyTool/src/Ringtoets.AssemblyTool.IO/Model/DataTypes/SerializableFailureMechanismAssemblyResult.cs
===================================================================
diff -u -rbb161675859d33b5bd868b5679b2cb09a6871b2d -r908ef4dfa4bb09ceacb29d33bdfe5680b6e50372
--- Ringtoets/AssemblyTool/src/Ringtoets.AssemblyTool.IO/Model/DataTypes/SerializableFailureMechanismAssemblyResult.cs (.../SerializableFailureMechanismAssemblyResult.cs) (revision bb161675859d33b5bd868b5679b2cb09a6871b2d)
+++ Ringtoets/AssemblyTool/src/Ringtoets.AssemblyTool.IO/Model/DataTypes/SerializableFailureMechanismAssemblyResult.cs (.../SerializableFailureMechanismAssemblyResult.cs) (revision 908ef4dfa4bb09ceacb29d33bdfe5680b6e50372)
@@ -62,7 +62,7 @@
///
/// Gets or sets the category group of this assembly result.
///
- [XmlElement(AssemblyXmlIdentifiers.AssessmentSectionCategoryGroup)]
+ [XmlElement(AssemblyXmlIdentifiers.FailureMechanismCategoryGroup)]
public SerializableFailureMechanismCategoryGroup CategoryGroup { get; set; }
///
Index: Ringtoets/AssemblyTool/src/Ringtoets.AssemblyTool.IO/Ringtoets.AssemblyTool.IO.csproj
===================================================================
diff -u -rb53d4c3c4221c2fcbc7b3c679e62d59a165fe8d4 -r908ef4dfa4bb09ceacb29d33bdfe5680b6e50372
--- Ringtoets/AssemblyTool/src/Ringtoets.AssemblyTool.IO/Ringtoets.AssemblyTool.IO.csproj (.../Ringtoets.AssemblyTool.IO.csproj) (revision b53d4c3c4221c2fcbc7b3c679e62d59a165fe8d4)
+++ Ringtoets/AssemblyTool/src/Ringtoets.AssemblyTool.IO/Ringtoets.AssemblyTool.IO.csproj (.../Ringtoets.AssemblyTool.IO.csproj) (revision 908ef4dfa4bb09ceacb29d33bdfe5680b6e50372)
@@ -18,6 +18,7 @@
+
Index: Ringtoets/AssemblyTool/test/Ringtoets.AssemblyTool.IO.Test/Model/DataTypes/SerializableAssessmentSectionAssemblyResultTest.cs
===================================================================
diff -u
--- Ringtoets/AssemblyTool/test/Ringtoets.AssemblyTool.IO.Test/Model/DataTypes/SerializableAssessmentSectionAssemblyResultTest.cs (revision 0)
+++ Ringtoets/AssemblyTool/test/Ringtoets.AssemblyTool.IO.Test/Model/DataTypes/SerializableAssessmentSectionAssemblyResultTest.cs (revision 908ef4dfa4bb09ceacb29d33bdfe5680b6e50372)
@@ -0,0 +1,68 @@
+// Copyright (C) Stichting Deltares 2017. All rights reserved.
+//
+// This file is part of Ringtoets.
+//
+// Ringtoets is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program. If not, see .
+//
+// All names, logos, and references to "Deltares" are registered trademarks of
+// Stichting Deltares and remain full property of Stichting Deltares at all times.
+// All rights reserved.
+
+using System;
+using Core.Common.TestUtil;
+using NUnit.Framework;
+using Ringtoets.AssemblyTool.IO.Model.DataTypes;
+using Ringtoets.AssemblyTool.IO.Model.Enums;
+using Ringtoets.AssemblyTool.IO.TestUtil;
+
+namespace Ringtoets.AssemblyTool.IO.Test.Model.DataTypes
+{
+ [TestFixture]
+ public class SerializableAssessmentSectionAssemblyResultTest
+ {
+ [Test]
+ public void DefaultConstructor_ReturnsDefaultValues()
+ {
+ // Call
+ var assemblyResult = new SerializableAssessmentSectionAssemblyResult();
+
+ // Assert
+ Assert.AreEqual((SerializableAssemblyMethod) 0, assemblyResult.AssemblyMethod);
+ Assert.AreEqual((SerializableAssessmentSectionCategoryGroup) 0, assemblyResult.CategoryGroup);
+ Assert.AreEqual("VOLLDG", assemblyResult.Status);
+
+ SerializableAttributeTestHelper.AssertXmlElementAttribute(
+ nameof(SerializableAssessmentSectionAssemblyResult.AssemblyMethod), "assemblagemethode");
+ SerializableAttributeTestHelper.AssertXmlElementAttribute(
+ nameof(SerializableAssessmentSectionAssemblyResult.CategoryGroup), "categorie");
+ SerializableAttributeTestHelper.AssertXmlElementAttribute(
+ nameof(SerializableAssessmentSectionAssemblyResult.Status), "status");
+ }
+
+ [Test]
+ public void Constructor_WithValidData_ReturnsExpectedValues()
+ {
+ // Setup
+ var random = new Random(39);
+ var category = random.NextEnumValue();
+ var assemblyMethod = random.NextEnumValue();
+
+ // Call
+ var assemblyResult = new SerializableAssessmentSectionAssemblyResult(assemblyMethod, category);
+ // Assert
+ Assert.AreEqual(category, assemblyResult.CategoryGroup);
+ Assert.AreEqual(assemblyMethod, assemblyResult.AssemblyMethod);
+ }
+ }
+}
\ No newline at end of file
Index: Ringtoets/AssemblyTool/test/Ringtoets.AssemblyTool.IO.Test/Ringtoets.AssemblyTool.IO.Test.csproj
===================================================================
diff -u -rb53d4c3c4221c2fcbc7b3c679e62d59a165fe8d4 -r908ef4dfa4bb09ceacb29d33bdfe5680b6e50372
--- Ringtoets/AssemblyTool/test/Ringtoets.AssemblyTool.IO.Test/Ringtoets.AssemblyTool.IO.Test.csproj (.../Ringtoets.AssemblyTool.IO.Test.csproj) (revision b53d4c3c4221c2fcbc7b3c679e62d59a165fe8d4)
+++ Ringtoets/AssemblyTool/test/Ringtoets.AssemblyTool.IO.Test/Ringtoets.AssemblyTool.IO.Test.csproj (.../Ringtoets.AssemblyTool.IO.Test.csproj) (revision 908ef4dfa4bb09ceacb29d33bdfe5680b6e50372)
@@ -15,6 +15,7 @@
+
Index: Ringtoets/AssemblyTool/src/Ringtoets.AssemblyTool.IO/Model/AssemblyXmlIdentifiers.cs
===================================================================
diff -u -rd25cb785f385ccf9a25b57aeeaf741a2c78ef356 -r908ef4dfa4bb09ceacb29d33bdfe5680b6e50372
--- Ringtoets/AssemblyTool/src/Ringtoets.AssemblyTool.IO/Model/AssemblyXmlIdentifiers.cs (.../AssemblyXmlIdentifiers.cs) (revision d25cb785f385ccf9a25b57aeeaf741a2c78ef356)
+++ Ringtoets/AssemblyTool/src/Ringtoets.AssemblyTool.IO/Model/AssemblyXmlIdentifiers.cs (.../AssemblyXmlIdentifiers.cs) (revision 908ef4dfa4bb09ceacb29d33bdfe5680b6e50372)
@@ -78,6 +78,11 @@
public const string AssessmentProcessIdRef = "BeoordelingsprocesIDRef";
///
+ /// Identifier for an assessment section category group element.
+ ///
+ public const string AssessmentSectionCategoryGroup = "categorie";
+
+ ///
/// Identifier for an assessment section ID reference attribute.
///
public const string AssessmentSectionIdRef = "WaterkeringstelselIDRef";
@@ -93,9 +98,9 @@
public const string AssessmentSection = "Waterkeringstelsel";
///
/// Identifier for an assessment section category group element.
///
- public const string AssessmentSectionCategoryGroup = "categorieTraject";
+ public const string FailureMechanismCategoryGroup = "categorieTraject";
///
/// Identifier for a bounded by element.
Fisheye: Tag 916d9bb347b0443e49f3e5c6e7d75b7c7f8c5ee6 refers to a dead (removed) revision in file `Ringtoets/AssemblyTool/src/Ringtoets.AssemblyTool.IO/Model/DataTypes/SerializableAssessmentSectionAssemblyResult.cs'.
@@ -93,9 +98,9 @@
public const string AssessmentSection = "Waterkeringstelsel";
///
- /// Identifier for an assessment section category group element.
+ /// Identifier for a failure mechanism category group element.
///
Fisheye: No comparison available. Pass `N' to diff?